#!/usr/bin/env python3
# Generate an array of 8-bit distance values from a distance field image

import argparse
from PIL import Image

# Create the parser and add arguments
parser = argparse.ArgumentParser(description='Generate an array of 8-bit distance values from a distance field image.')
parser.add_argument('in_image', metavar='input_image', type=str, help='the path to the input image file')
parser.add_argument('-u', '--unsigned', action='store_true', help='output unsigned values')

# Parse the arguments
args = parser.parse_args()

# Open an image file
image = Image.open(args.in_image)

# Convert the image to grayscale
grayscale_img = image.convert('L')

# Get the pixel values of the grayscale image
pixels = grayscale_img.load()
w = grayscale_img.size[0]
h = grayscale_img.size[1]

data = []

for y in range(h):
  for x in range(w):
    p = pixels[x, y]
    data.append(p if args.unsigned else p - 128)

for y in range(h):
  line = ""
  for x in range(w):
    line += "0x" + format(data[y*w + x] & 255, '02X') + ","
  print(' '*4 + line)

